@@ -3,7 +3,7 @@ typedload
 This module is the inverse of dataloader. It converts typed
 data structures to things that json can serialize.
 """
-# Copyright (C) 2018-2019 Salvo "LtWorf" Tomaselli
+# Copyright (C) 2018-2020 Salvo "LtWorf" Tomaselli
 #
 # typedload is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -22,6 +22,7 @@ data structures to things that json can serialize.
 
 import datetime
 from enum import Enum
+from pathlib import Path
 from typing import *
 
 from .exceptions import TypedloadValueError
@@ -102,6 +103,7 @@ class Dumper:
             (lambda value: isinstance(value, Enum), lambda l, value: l.dump(value.value)),
             (lambda value: isinstance(value, Dict), lambda l, value: {l.dump(k): l.dump(v) for k, v in value.items()}),
             (lambda value: isinstance(value, (datetime.date, datetime.time)), _datetimedump),
+            (lambda value: isinstance(value, Path), lambda l, value: str(value)),
             (is_attrs, _attrdump),
         ]  # type: List[Tuple[Callable[[Any], bool],Callable[['Dumper', Any], Any]]]
 
@@ -125,7 +127,7 @@ class Dumper:
                 match = False
             if match:
                 return i
-        raise TypedloadValueError('Unable to dump %s' % value, value=value)
+        raise TypedloadValueError('Unable to dump %s' % value, value=value, type_=type(value))
 
     def dump(self, value: Any) -> Any:
         """
