@@ -15,7 +15,7 @@ protects the user from the ever changing internal representation used in
 different versions of Python.
 """
 
-# Copyright (C) 2019 Salvo "LtWorf" Tomaselli
+# Copyright (C) 2019-2020 Salvo "LtWorf" Tomaselli
 #
 # typedload is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -66,12 +66,14 @@ except ImportError:
     from typing import _ForwardRef as ForwardRef  # type: ignore
 
 
+Literal = None  # type: Any
+_TypedDictMeta = None  # type: Any
 try:
     # Since 3.8
     from typing import Literal, _TypedDictMeta  # type: ignore
 except ImportError:
-    Literal = None
-    _TypedDictMeta = None
+    pass
+
 
 def _issubclass(t1, t2) -> bool:
     """
@@ -121,7 +123,7 @@ def is_nonetype(type_: Type[Any]) -> bool:
     return type_ == NONETYPE
 
 
-def _generic_type_check(type_: Type[Any], native, from_typing):
+def _generic_type_check(type_: Type[Any], native, from_typing) -> bool:
     return getattr(type_, '__origin__', None) in {native, from_typing} or getattr(type_, '__extra__', None) == native
 
 
